<?php

namespace Drupal\splitting_ui;

use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\PagerSelectExtender;

/**
 * Splitting manager.
 */
class SplittingManager implements SplittingManagerInterface {

  /**
   * The database connection used to check the target against.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Constructs a SplittingManager object.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection which will be used to check the target against.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public function isSplitting($target) {
    return (bool) $this->connection->query("SELECT * FROM {splitting} WHERE [target] = :target", [':target' => $target])
      ->fetchField();
  }

  /**
   * {@inheritdoc}
   */
  public function findAll($keys = '') {
    $query = $this->connection
      ->select('splitting', 't')
      ->extend(PagerSelectExtender::class)
      ->limit(50)
      ->fields('t');

    if (!empty(trim($keys))) {
      // Escape for LIKE matching.
      $keys = $this->connection->escapeLike($keys);
      // Replace wildcards with MySQL/PostgreSQL wildcards.
      $keys = preg_replace('!\*+!', '%', $keys);
      // Run the query to find matching targets.
      $query->condition('target', '%' . $keys . '%', 'LIKE');
    }

    return $query->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function addTarget($splitting_id, $target, $options) {
    $this->connection->merge('splitting')
      ->key([
        'sid'    => $splitting_id,
      ])
      ->fields([
        'target'  => $target,
        'options' => $options,
      ])
      ->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function removeTarget($splitting_id) {
    $this->connection->delete('splitting')
      ->condition('sid', $splitting_id)
      ->execute();
  }

  /**
   * {@inheritdoc}
   */
  public function findById($splitting_id) {
    return $this->connection->query("SELECT [target], [options] FROM {splitting} WHERE [sid] = :sid", [':sid' => $splitting_id])
      ->fetchAssoc();
  }

}
