<?php

namespace Drupal\splitting_ui;

/**
 * Provides an interface defining a Splitting manager.
 */
interface SplittingManagerInterface {

  /**
   * Returns if this Splitting target is added.
   *
   * @param string $target
   *   The Splitting target to check.
   *
   * @return bool
   *   TRUE if the Splitting target is added, FALSE otherwise.
   */
  public function isSplitting($target);

  /**
   * Finds all added Splitting target.
   *
   * @param string $keys
   *   The Splitting search key to filter target.
   *
   * @return \Drupal\Core\Database\StatementInterface
   *   The result of the database query.
   */
  public function findAll($keys);

  /**
   * Add a Splitting target.
   *
   * @param int $splitting_id
   *   The Splitting id for edit.
   * @param string $target
   *   The Splitting target to add.
   * @param string $options
   *   The Splitting target options.
   */
  public function addTarget($splitting_id, $target, $options);

  /**
   * Remove a Splitting target.
   *
   * @param int $splitting_id
   *   The Splitting id to remove.
   */
  public function removeTarget($splitting_id);

  /**
   * Finds an added Splitting target by its ID.
   *
   * @param int $splitting_id
   *   The ID for an added Splitting target.
   *
   * @return string|false
   *   Either the added Splitting target or FALSE if none exist with that ID.
   */
  public function findById($splitting_id);

}
